# Modeling Best Practices
### On this page
  * [Modeling Major IT Systems](https://help.sap.com/docs/leanix/ea/modeling-best-practices?version=CLOUD#modeling-major-it-systems)
  * [Import Templates](https://help.sap.com/docs/leanix/ea/modeling-best-practices?version=CLOUD#import-templates)


Best practices for modeling major IT systems.
**Note**
For general guidelines and best practices for modeling applications and all other architectural elements, see [Fact Sheet Modeling Guidelines](https://help.sap.com/docs/leanix/ea/fact-sheet-modeling-guidelines?locale=en-US&state=PRODUCTION&version=CLOUD).
